/*
 * Copyright (C) 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package android.tools.traces.events

/**
 * From com.android.internal.jank.InteractionJankMonitor.
 *
 * NOTE: Make sure order is the same as in {@see com.android.internal.jank.InteractionJankMonitor}.
 */
// TODO: Can we re-use to enum generated from the proto stats/enums/jank/enums.proto?
enum class CujType(val id: Int) {
    CUJ_NOTIFICATION_SHADE_EXPAND_COLLAPSE(0),
    CUJ_NOTIFICATION_SHADE_SCROLL_FLING(2),
    CUJ_NOTIFICATION_SHADE_ROW_EXPAND(3),
    CUJ_NOTIFICATION_SHADE_ROW_SWIPE(4),
    CUJ_NOTIFICATION_SHADE_QS_EXPAND_COLLAPSE(5),
    CUJ_NOTIFICATION_SHADE_QS_SCROLL_SWIPE(6),
    CUJ_LAUNCHER_APP_LAUNCH_FROM_RECENTS(7),
    CUJ_LAUNCHER_APP_LAUNCH_FROM_ICON(8),
    CUJ_LAUNCHER_APP_CLOSE_TO_HOME(9),
    CUJ_LAUNCHER_APP_CLOSE_TO_PIP(10),
    CUJ_LAUNCHER_QUICK_SWITCH(11),
    CUJ_NOTIFICATION_HEADS_UP_APPEAR(12),
    CUJ_NOTIFICATION_HEADS_UP_DISAPPEAR(13),
    CUJ_NOTIFICATION_ADD(14),
    CUJ_NOTIFICATION_REMOVE(15),
    CUJ_NOTIFICATION_APP_START(16),
    CUJ_LOCKSCREEN_PASSWORD_APPEAR(17),
    CUJ_LOCKSCREEN_PATTERN_APPEAR(18),
    CUJ_LOCKSCREEN_PIN_APPEAR(19),
    CUJ_LOCKSCREEN_PASSWORD_DISAPPEAR(20),
    CUJ_LOCKSCREEN_PATTERN_DISAPPEAR(21),
    CUJ_LOCKSCREEN_PIN_DISAPPEAR(22),
    CUJ_LOCKSCREEN_TRANSITION_FROM_AOD(23),
    CUJ_LOCKSCREEN_TRANSITION_TO_AOD(24),
    CUJ_LAUNCHER_OPEN_ALL_APPS(25),
    CUJ_LAUNCHER_ALL_APPS_SCROLL(26),
    CUJ_LAUNCHER_APP_LAUNCH_FROM_WIDGET(27),
    CUJ_SETTINGS_PAGE_SCROLL(28),
    CUJ_LOCKSCREEN_UNLOCK_ANIMATION(29),
    CUJ_SHADE_APP_LAUNCH_FROM_HISTORY_BUTTON(30),
    CUJ_SHADE_APP_LAUNCH_FROM_MEDIA_PLAYER(31),
    CUJ_SHADE_APP_LAUNCH_FROM_QS_TILE(32),
    CUJ_SHADE_APP_LAUNCH_FROM_SETTINGS_BUTTON(33),
    CUJ_STATUS_BAR_APP_LAUNCH_FROM_CALL_CHIP(34),
    CUJ_PIP_TRANSITION(35),
    CUJ_WALLPAPER_TRANSITION(36),
    CUJ_USER_SWITCH(37),
    CUJ_SPLASHSCREEN_AVD(38),
    CUJ_SPLASHSCREEN_EXIT_ANIM(39),
    CUJ_SCREEN_OFF(40),
    CUJ_SCREEN_OFF_SHOW_AOD(41),
    CUJ_ONE_HANDED_ENTER_TRANSITION(42),
    CUJ_ONE_HANDED_EXIT_TRANSITION(43),
    CUJ_UNFOLD_ANIM(44),
    CUJ_SUW_LOADING_TO_SHOW_INFO_WITH_ACTIONS(45),
    CUJ_SUW_SHOW_FUNCTION_SCREEN_WITH_ACTIONS(46),
    CUJ_SUW_LOADING_TO_NEXT_FLOW(47),
    CUJ_SUW_LOADING_SCREEN_FOR_STATUS(48),
    CUJ_SPLIT_SCREEN_ENTER(49),
    CUJ_SPLIT_SCREEN_EXIT(50),
    CUJ_LOCKSCREEN_LAUNCH_CAMERA(51),
    CUJ_SPLIT_SCREEN_RESIZE(52),
    CUJ_SETTINGS_SLIDER(53),
    CUJ_TAKE_SCREENSHOT(54),
    CUJ_VOLUME_CONTROL(55),
    CUJ_BIOMETRIC_PROMPT_TRANSITION(56),
    CUJ_SETTINGS_TOGGLE(57),
    CUJ_SHADE_DIALOG_OPEN(58),
    CUJ_USER_DIALOG_OPEN(59),
    CUJ_TASKBAR_EXPAND(60),
    CUJ_TASKBAR_COLLAPSE(61),
    CUJ_SHADE_CLEAR_ALL(62),
    CUJ_LAUNCHER_UNLOCK_ENTRANCE_ANIMATION(63),
    CUJ_LOCKSCREEN_OCCLUSION(64),
    CUJ_RECENTS_SCROLLING(65),
    CUJ_LAUNCHER_APP_SWIPE_TO_RECENTS(66),
    CUJ_LAUNCHER_CLOSE_ALL_APPS_SWIPE(67),
    CUJ_LAUNCHER_CLOSE_ALL_APPS_TO_HOME(68),
    CUJ_LOCKSCREEN_CLOCK_MOVE_ANIMATION(70),
    CUJ_LAUNCHER_OPEN_SEARCH_RESULT(71),

    // 72 - 77 are reserved for b/281564325.

    CUJ_LAUNCHER_APP_CLOSE_TO_HOME_FALLBACK(78),
    CUJ_SHADE_EXPAND_FROM_STATUS_BAR(79),
    CUJ_IME_INSETS_SHOW_ANIMATION(80),
    CUJ_IME_INSETS_HIDE_ANIMATION(81),

    // KEEP AS LAST TYPE
    // used to handle new types that haven't been added here yet but might be dumped by the platform
    UNKNOWN(-1);

    companion object {
        fun from(eventId: Int): CujType = values().firstOrNull { it.id == eventId } ?: UNKNOWN
    }
}
