/*
 * Copyright (C) 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.layoutlib.test.myapplication;

import android.content.Context;
import android.util.AttributeSet;
import android.view.ContextThemeWrapper;
import android.view.LayoutInflater;
import android.widget.FrameLayout;

public class ThemableWidget extends FrameLayout {
    public ThemableWidget(Context context) {
        super(context);

        init();
    }

    public ThemableWidget(Context context, AttributeSet attrs) {
        super(context, attrs);

        init();
    }

    public ThemableWidget(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);

        init();
    }

    public ThemableWidget(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);

        init();
    }

    private void init() {
        ContextThemeWrapper context = new ContextThemeWrapper(getContext(), getContext().getTheme());
        context.setTheme(R.style.ThemableWidgetStyle);

        LayoutInflater.from(context).inflate(R.layout.themable_widget_layout, this);
    }
}
